@@ -14,9 +14,10 @@
 fortify_sfc <- function(sfc_df, keep = NULL) {
   
   sfc_df <- sf::st_as_sf(sfc_df)
-  if (!is.null(keep)) {
-    sfc_df <- sfc_df %>% mutate(geometry = rmapshaper::ms_simplify(sfc_df$geometry, keep = keep, keep_shapes = TRUE))
-  }
+  #if (!is.null(keep)) {
+  #  sfc_df <- sfc_df %>% mutate(geometry = rmapshaper::ms_simplify(sfc_df$geometry, keep = keep, keep_shapes = TRUE))
+  #}
+  # keep will not be used now
 
   sf_tbl <- sfc_df %>%
     mutate(geom = purrr::map(!!sym("geometry"), function(x) {
